@@ -23,64 +23,56 @@ from aliyunsdkvod.endpoint import endpoint_data
 class AddEditingProjectRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'AddEditingProject')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'AddEditingProject','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # String
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_Description(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # String
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_Title(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_Title(self): # String
 		return self.get_query_params().get('Title')
 
-	def set_Title(self,Title):
-		self.add_query_param('Title',Title)
-
-	def get_CoverURL(self):
+	def set_Title(self, Title):  # String
+		self.add_query_param('Title', Title)
+	def get_CoverURL(self): # String
 		return self.get_query_params().get('CoverURL')
 
-	def set_CoverURL(self,CoverURL):
-		self.add_query_param('CoverURL',CoverURL)
-
-	def get_Division(self):
+	def set_CoverURL(self, CoverURL):  # String
+		self.add_query_param('CoverURL', CoverURL)
+	def get_Division(self): # String
 		return self.get_query_params().get('Division')
 
-	def set_Division(self,Division):
-		self.add_query_param('Division',Division)
-
-	def get_ResourceOwnerAccount(self):
+	def set_Division(self, Division):  # String
+		self.add_query_param('Division', Division)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # String
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Timeline(self):
+	def set_OwnerId(self, OwnerId):  # String
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Timeline(self): # String
 		return self.get_query_params().get('Timeline')
 
-	def set_Timeline(self,Timeline):
-		self.add_query_param('Timeline',Timeline)
\ No newline at end of file
+	def set_Timeline(self, Timeline):  # String
+		self.add_query_param('Timeline', Timeline)
