@@ -25,14 +25,14 @@ class DeleteAIImageInfosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteAIImageInfos','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AIImageInfoIds(self):
+	def get_AIImageInfoIds(self): # String
 		return self.get_query_params().get('AIImageInfoIds')
 
-	def set_AIImageInfoIds(self,AIImageInfoIds):
-		self.add_query_param('AIImageInfoIds',AIImageInfoIds)
\ No newline at end of file
+	def set_AIImageInfoIds(self, AIImageInfoIds):  # String
+		self.add_query_param('AIImageInfoIds', AIImageInfoIds)
