@@ -25,14 +25,14 @@ class DeleteAttachedMediaRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteAttachedMedia','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_MediaIds(self):
+	def get_MediaIds(self): # String
 		return self.get_query_params().get('MediaIds')
 
-	def set_MediaIds(self,MediaIds):
-		self.add_query_param('MediaIds',MediaIds)
\ No newline at end of file
+	def set_MediaIds(self, MediaIds):  # String
+		self.add_query_param('MediaIds', MediaIds)
