@@ -23,34 +23,31 @@ from aliyunsdkvod.endpoint import endpoint_data
 class DescribePlayTopVideosRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribePlayTopVideos')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribePlayTopVideos','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageSize(self):
+	def get_PageSize(self): # Long
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_OwnerId(self):
+	def set_PageSize(self, PageSize):  # Long
+		self.add_query_param('PageSize', PageSize)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_BizDate(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_BizDate(self): # String
 		return self.get_query_params().get('BizDate')
 
-	def set_BizDate(self,BizDate):
-		self.add_query_param('BizDate',BizDate)
-
-	def get_PageNo(self):
+	def set_BizDate(self, BizDate):  # String
+		self.add_query_param('BizDate', BizDate)
+	def get_PageNo(self): # Long
 		return self.get_query_params().get('PageNo')
 
-	def set_PageNo(self,PageNo):
-		self.add_query_param('PageNo',PageNo)
\ No newline at end of file
+	def set_PageNo(self, PageNo):  # Long
+		self.add_query_param('PageNo', PageNo)
