@@ -23,52 +23,46 @@ from aliyunsdkvod.endpoint import endpoint_data
 class DescribeVodTranscodeDataRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribeVodTranscodeData')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribeVodTranscodeData','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_StartTime(self):
+	def get_StartTime(self): # String
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_Storage(self):
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_Storage(self): # String
 		return self.get_query_params().get('Storage')
 
-	def set_Storage(self,Storage):
-		self.add_query_param('Storage',Storage)
-
-	def get_EndTime(self):
+	def set_Storage(self, Storage):  # String
+		self.add_query_param('Storage', Storage)
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_Specification(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_Specification(self): # String
 		return self.get_query_params().get('Specification')
 
-	def set_Specification(self,Specification):
-		self.add_query_param('Specification',Specification)
-
-	def get_OwnerId(self):
+	def set_Specification(self, Specification):  # String
+		self.add_query_param('Specification', Specification)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Interval(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Interval(self): # String
 		return self.get_query_params().get('Interval')
 
-	def set_Interval(self,Interval):
-		self.add_query_param('Interval',Interval)
-
-	def get_Region(self):
+	def set_Interval(self, Interval):  # String
+		self.add_query_param('Interval', Interval)
+	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
-	def set_Region(self,Region):
-		self.add_query_param('Region',Region)
\ No newline at end of file
+	def set_Region(self, Region):  # String
+		self.add_query_param('Region', Region)
