@@ -25,14 +25,14 @@ class GetAppInfosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'GetAppInfos','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppIds(self):
+	def get_AppIds(self): # String
 		return self.get_query_params().get('AppIds')
 
-	def set_AppIds(self,AppIds):
-		self.add_query_param('AppIds',AppIds)
\ No newline at end of file
+	def set_AppIds(self, AppIds):  # String
+		self.add_query_param('AppIds', AppIds)
