@@ -25,14 +25,14 @@ class GetTranscodeTaskRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'GetTranscodeTask','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TranscodeTaskId(self):
+	def get_TranscodeTaskId(self): # String
 		return self.get_query_params().get('TranscodeTaskId')
 
-	def set_TranscodeTaskId(self,TranscodeTaskId):
-		self.add_query_param('TranscodeTaskId',TranscodeTaskId)
\ No newline at end of file
+	def set_TranscodeTaskId(self, TranscodeTaskId):  # String
+		self.add_query_param('TranscodeTaskId', TranscodeTaskId)
