@@ -25,14 +25,14 @@ class GetVideoInfosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'GetVideoInfos','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_VideoIds(self):
+	def get_VideoIds(self): # String
 		return self.get_query_params().get('VideoIds')
 
-	def set_VideoIds(self,VideoIds):
-		self.add_query_param('VideoIds',VideoIds)
\ No newline at end of file
+	def set_VideoIds(self, VideoIds):  # String
+		self.add_query_param('VideoIds', VideoIds)
