@@ -23,28 +23,26 @@ from aliyunsdkvod.endpoint import endpoint_data
 class SetAuditSecurityIpRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'SetAuditSecurityIp')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'SetAuditSecurityIp','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SecurityGroupName(self):
+	def get_SecurityGroupName(self): # String
 		return self.get_query_params().get('SecurityGroupName')
 
-	def set_SecurityGroupName(self,SecurityGroupName):
-		self.add_query_param('SecurityGroupName',SecurityGroupName)
-
-	def get_OperateMode(self):
+	def set_SecurityGroupName(self, SecurityGroupName):  # String
+		self.add_query_param('SecurityGroupName', SecurityGroupName)
+	def get_OperateMode(self): # String
 		return self.get_query_params().get('OperateMode')
 
-	def set_OperateMode(self,OperateMode):
-		self.add_query_param('OperateMode',OperateMode)
-
-	def get_Ips(self):
+	def set_OperateMode(self, OperateMode):  # String
+		self.add_query_param('OperateMode', OperateMode)
+	def get_Ips(self): # String
 		return self.get_query_params().get('Ips')
 
-	def set_Ips(self,Ips):
-		self.add_query_param('Ips',Ips)
\ No newline at end of file
+	def set_Ips(self, Ips):  # String
+		self.add_query_param('Ips', Ips)
