@@ -23,46 +23,41 @@ from aliyunsdkvod.endpoint import endpoint_data
 class SetEditingProjectMaterialsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'SetEditingProjectMaterials')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'SetEditingProjectMaterials','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # String
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ProjectId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # String
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ProjectId(self): # String
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ProjectId(self, ProjectId):  # String
+		self.add_query_param('ProjectId', ProjectId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # String
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_MaterialIds(self):
+	def set_OwnerId(self, OwnerId):  # String
+		self.add_query_param('OwnerId', OwnerId)
+	def get_MaterialIds(self): # String
 		return self.get_query_params().get('MaterialIds')
 
-	def set_MaterialIds(self,MaterialIds):
-		self.add_query_param('MaterialIds',MaterialIds)
\ No newline at end of file
+	def set_MaterialIds(self, MaterialIds):  # String
+		self.add_query_param('MaterialIds', MaterialIds)
