@@ -25,14 +25,14 @@ class UpdateImageInfosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'vod', '2017-03-21', 'UpdateImageInfos','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UpdateContent(self):
+	def get_UpdateContent(self): # String
 		return self.get_query_params().get('UpdateContent')
 
-	def set_UpdateContent(self,UpdateContent):
-		self.add_query_param('UpdateContent',UpdateContent)
\ No newline at end of file
+	def set_UpdateContent(self, UpdateContent):  # String
+		self.add_query_param('UpdateContent', UpdateContent)
